/**
 * Provides component for rendering elements written in SJDON notation.
 */
export class SuiWeb
{
    /**
     * Renders the specified {@link data `data`} and appends it to the specified {@link element `element`}.
     *
     * @param {NodeDescriptor} data
     * The node to render written in SJDON notation.
     *
     * @param {HTMLElement} element
     * The element to add the rendered node to.
     */
    static render(data, element)
    {
        if (Array.isArray(data))
        {
            let descriptor = data[0];
            let args = data.slice(1);

            if (typeof descriptor === "function")
            {
                SuiWeb.render(descriptor(...args), element);
            }
            else if (typeof descriptor === "string")
            {
                let result = element.ownerDocument.createElement(descriptor);
                element.appendChild(result);

                for (let arg of args)
                {
                    if (typeof arg === "object" && !Array.isArray(arg))
                    {
                        Object.assign(result, arg);
                    }
                    else
                    {
                        SuiWeb.render(arg, result);
                    }
                }
            }
            else
            {
                throw new SyntaxError();
            }
        }
        else if (typeof data === "string")
        {
            element.appendChild(element.ownerDocument.createTextNode(data));
        }
        else
        {
            throw new SyntaxError();
        }
    }
}
